#
# spec file for package rpmlint
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rpmlint
Version:        1.10
Release:        150000.7.70.1
Summary:        RPM file correctness checker
License:        GPL-2.0-or-later
Group:          System/Packages
Url:            https://github.com/rpm-software-management/rpmlint
Source0:        https://github.com/rpm-software-management/rpmlint/archive/rpmlint-%{version}.tar.gz
Source1:        rpmlint-checks-master.tar.xz
Source2:        config
Source11:       pie.config
Source12:       licenses.config
Source99:       README.packaging.txt
Source100:      syntax-validator.py
Patch00:        rpmlint-suse.diff
Patch01:        suse-checks.diff
Patch02:        suse-version.diff
Patch03:        suse-url-check.diff
Patch04:        suse-python3-naming-policy.diff
Patch05:        suse-tests-without-badness.patch
Patch06:        suse-pkg-config-check.diff
Patch07:        suse-binarieschecks.diff
Patch08:        no-doc-for-lib.diff
Patch09:        suse-filter-exception.diff
Patch10:        suse-spdx-license-exceptions.patch
Patch11:        suse-skip-macro-expansion.diff
Patch20:        usr-arch.diff
Patch23:        suse-filter-more-verbose.diff
Patch24:        docdata-examples.diff
Patch25:        yast-provides.diff
Patch27:        better-wrong-script.diff
Patch28:        buildroot-doc.diff
Patch29:        rpmgroup-checks.diff
Patch30:        devel-provide-is-devel-package.diff
Patch31:        only-reg-files-are-scripts.diff
Patch32:        buildroot-in-scripts.diff
Patch33:        libtool-wrapper-check.diff
Patch35:        noarch-lib64.diff
Patch37:        description-check.diff
Patch38:        0001-Tighten-wrong-script-interpreter-check-to-lower-fals.patch
Patch39:        selfconflicts-provide.diff
Patch40:        no-badness-return.diff
Patch41:        suse-shlib-devel-dependency.diff
Patch42:        0001-Improve-XDG-Menu-checks-stability.patch
Patch43:        stricter-interpreter-check.diff
Patch44:        confusing-invalid-spec-name.diff
Patch48:        suse-whitelist-opensuse.diff
Patch49:        extend-suse-conffiles-check.diff
Patch50:        compressed-backup-regex.diff
Patch51:        suse-speccheck-utf8.diff
Patch52:        0001-Accept-python-abi-as-a-valid-versioned-python-depend.patch
Patch54:        suse-ignore-specfile-errors.diff
Patch55:        invalid-filerequires.diff
Patch57:        check-for-self-provides.diff
Patch58:        remove-ghostfile-checks.diff
Patch59:        0001-Extend-scm_regex-to-capture-more-SCM-system-files.patch
Patch60:        0003-Tighten-lib_regex-to-avoid-false-positive-in-python-.patch
Patch61:        0001-Execute-chroot-tests-also-on-x86-rpms.patch
Patch62:        ignore-readelf-ar-error.diff
Patch63:        fix-diag-sortorder.diff
Patch64:        drop-unicodedata-dep.diff
Patch65:        0001-split-wrong-script-interpreter-into-env-script-inter.patch
Patch66:        0001-Handle-post-scripts-that-contain-non-ascii-character.patch
Patch67:        omit_BUILDROOT_from_pyo_files.patch
Patch68:        0001-Avoid-false-positives-on-is_elf-check.patch
Patch69:        0007-Validate-Appdata-also-when-appstream-util-is-unavail.patch
Patch71:        0001-Avoid-calling-close-on-undefined-fd-variable.patch
Patch72:        rpmlint-slpp-NUM-NUM.patch
Patch73:        0001-Binariescheck-Check-for-chroot-chdir-on-ARM-PPC.patch
Patch74:        0001-Always-import-XDG-desktop-files-as-utf8.patch
Patch75:        0001-Fix-compatibility-with-file-5.33.patch
Patch76:        update-magic-values-python-37.patch
Patch77:        suse-rpmlint-all-pie.patch
Patch78:        0001-Backport-d8f423b575e8be387d33bc3af176baf978efacbb.patch
Patch80:        accept-licenses-with-plus.patch
BuildRequires:  obs-service-format_spec_file
BuildRequires:  python3-flake8
BuildRequires:  python3-pytest
BuildRequires:  python3-rpm
BuildRequires:  xz
#!BuildIgnore:  rpmlint-mini
Requires:       %{_bindir}/readelf
Requires:       bash
Requires:       checkbashisms
Requires:       cpio
Requires:       dash
Requires:       desktop-file-utils
Requires:       file
Requires:       findutils
Requires:       python3-magic
Requires:       python3-pybeam
Requires:       python3-rpm
Requires:       python3-xml
BuildArch:      noarch

%description
rpmlint is a tool to check common errors on RPM packages. Binary and
source packages can be checked.

%prep
%autosetup -n rpmlint-rpmlint-%{version} -a1 -p1

cp -p %{SOURCE2} .
chmod a-x rpmlint-checks-master/*.py
# Only move top-level python files
mv rpmlint-checks-master/*.py .

%build
make %{?_smp_mflags} PYTHON=%{_bindir}/python3

%install
%make_install PYTHON=%{_bindir}/python3
# the provided bash-completion does not work and only prints bash errors
rm -rf  %{buildroot}%{_sysconfdir}/bash_completion.d
mv %{buildroot}%{_sysconfdir}/rpmlint/config %{buildroot}%{_datadir}/rpmlint/config
head -n 8 %{buildroot}%{_datadir}/rpmlint/config > %{buildroot}%{_sysconfdir}/rpmlint/config
# make sure that the package is sane
for f in %{buildroot}%{_datadir}/rpmlint/*.py %{buildroot}%{_datadir}/rpmlint/config; do
    echo $f
    env LC_ALL=C.utf8 python3 -tt %{SOURCE100} $f
done
install -m 644 %{SOURCE11} %{buildroot}/%{_sysconfdir}/rpmlint/

cp %{SOURCE12} licenses.config
# note there is a tab character behind the -d, so don't copy&paste lightly
cut '-d	' -f1 %{_prefix}/lib/obs/service/format_spec_file.files/licenses_changes.txt | tail -n +2 | sort -u | while read l; do
  sed -i -e "s/\(#VALIDLICENSES\)/\1\n	'$l',/" licenses.config
done
# add some deprecated licenses we allow for now
for l in AGPL-3.0 GFDL-1.1 GFDL-1.2 GFDL-1.3 GPL-3.0-with-GCC-exception \
   GPL-2.0-with-classpath-exception GPL-2.0-with-font-exception SUSE-LGPL-2.1+-with-GCC-exception SUSE-NonFree \
   GPL-1.0 GPL-2.0 GPL-3.0 LGPL-2.0 LGPL-2.1 LGPL-3.0; do
  sed -i -e "s/\(#VALIDLICENSES\)/\1\n  '$l',/" licenses.config
done
install -m 644  licenses.config %{buildroot}/%{_sysconfdir}/rpmlint/

%check
env PYTHON=%{_bindir}/python3 ./test.sh

%files
%license COPYING
%doc README*
%{_bindir}/rpmlint
%{_bindir}/rpmdiff
%{_datadir}/rpmlint
%config(noreplace) %{_sysconfdir}/rpmlint/config
%config %{_sysconfdir}/rpmlint/pie.config
%config %{_sysconfdir}/rpmlint/licenses.config
%dir %{_sysconfdir}/rpmlint
%{_mandir}/man1/rpmlint.1%{ext_man}
%{_mandir}/man1/rpmdiff.1%{ext_man}

%changelog
* Tue Jul 18 2023 matthias.gerstner@suse.com
- fix oddjob-gpupdate whitelisting (bsc#1188680). Needs to be the basename
  only.
* Tue Apr 18 2023 filippo.bonazzi@suse.com
- backport of usbguard dbus whitelisting (bsc#1206414)
* Thu Mar 16 2023 wolfgang.frisch@suse.com
- backport of kinfocenter5 whitelisting for D-Bus (bsc#1209378)
* Thu Jul 28 2022 matthias.gerstner@suse.com
- backport of oddjob-gpupdate whitelisting for D-Bus (bsc#1188680)
* Wed Jul  6 2022 matthias.gerstner@suse.com
- adjust NetworkManager priv helper spelling in whitelisting (bsc#1201207)
* Fri Apr 29 2022 matthias.gerstner@suse.com
- whitelist kcron (bsc#1199006)
* Mon Apr 25 2022 wolfgang.frisch@suse.com
- Backport of power-profiles-daemon (bsc#1198693).
* Tue Apr 19 2022 matthias.gerstner@suse.com
- fix kpmcore, nm-priv and tukitd whitelistings that contained absolute paths
  instead of only the basenames (bsc#1198521)
* Fri Apr  1 2022 wolfgang.frisch@suse.com
- Backport of deepin-api (bsc#1196681 bsc#1070943)
* Tue Mar 15 2022 jsegitz@suse.com
- backport of openSUSE transactional updates dbus whitelist (bsc#1196149)
* Wed Mar  9 2022 matthias.gerstner@suse.com
- backport of kpmcore whitelisting (bsc#1178848)
* Thu Feb 24 2022 matthias.gerstner@suse.com
- backport NetworkManager nm-priv helper whitelisting for SLE-15-SP4 (bsc#1194799)
* Wed Feb  9 2022 wolfgang.frisch@suse.com
- Backport whitelisting of kdenetwork-filesharing (bsc#1195548).
- Backport whitelisting of powerdevil5 (bsc#1195662).
* Thu Feb  3 2022 wolfgang.frisch@suse.com
- Backport whitelisting of plasma5-disks (bsc#1195491).
* Tue Jan 25 2022 danilo.spinella@suse.com
- Add accept-licenses-with-plus.patch to accept any license ending
  with a + (as indicated in the SPDX syntax), fixes bsc#1195085
- Remove licenses ending with + from valid license array
* Thu Oct 21 2021 paolo.perego@suse.com
- Whitelist pam_u2f (bsc#1190790 jsc#SLE-21888)
* Tue Oct 19 2021 paolo.perego@suse.com
- Backport whitelisting of systemd-homed (bsc#1191821)
* Mon Aug 16 2021 wolfgang.frisch@suse.com
- Backport whitelisting of oddjob (bsc#1189106 bsc#1169494).
* Mon Nov 23 2020 jsegitz@suse.com
- Whitelist PAM modules and DBUS rules for cockpit (bsc#1169614)
* Thu Oct 15 2020 matthias.gerstner@suse.com
- backport pam_pwquality whitelisting for PackageHub (bsc#1177684)
* Fri Oct  9 2020 matthias.gerstner@suse.com
- backport systemd portable1 D-Bus whitelisting (bsc#1176676)
* Tue Apr 14 2020 malte.kraus@suse.com
- whitelist certmonger (bsc#1169365, bsc#1129452)
* Thu Nov 28 2019 malte.kraus@suse.com
- whitelist sssd infopipe (bsc#1157663)
- whitelist sysprof3 D-Bus services (bsc#1151418)
* Wed Jan  9 2019 opensuse-packaging@opensuse.org
- Update rpmlint-checks to version master (bsc#1116686):
  * Ignore decoding errors as we're not sure we know the encoding
  * Use UTF-8 encoding when opening .pc file (#42)
  * whitelist otrs permission file (#41)
  * Relax various flake8 warnings
  * Handle '-n' option for %%service_del_preun %%service_del_postun
  * There isn't a good standard, whether the directory should be called 'tests/' or 'test/'
* Wed Jan  2 2019 mliska@suse.cz
- Add 0001-Backport-d8f423b575e8be387d33bc3af176baf978efacbb.patch
* Fri Dec 21 2018 matthias.gerstner@suse.com
- whitelist boltd dbus service (bsc#1119975)
* Wed Dec 12 2018 mardnh@gmx.de
- Add user/group 'bird' for package bird (network/bird)
* Fri Dec  7 2018 toddrme2178@gmail.com
- Add xrootd gid and uid whitelist.
  This is needed by the latest versions of xrootd.
* Mon Dec  3 2018 matthias.gerstner@suse.com
- whitelist pam_slurm_adopt (bsc#1116758)
* Tue Nov 20 2018 eich@suse.com
- Add group 'singularity', remove user 'singularity' which was
  added mistakenly.
* Tue Nov 20 2018 eich@suse.com
- Add user/group 'slurm' for package slurm
  (See network:cluster/slurm) (FATE#316379).
* Fri Nov 16 2018 alarrosa@suse.com
- Add mpd user
* Fri Nov 16 2018 dmueller@suse.com
- update libtool-wrapper-check.diff to handle inaccessible files
* Thu Nov  8 2018 jsegitz@suse.com
- whitelist keepalived dbus service (bsc#1015141)
* Tue Oct 23 2018 matthias.gerstner@suse.com
- remove openswan whitelisting (deleted from Factory, replaced by libreswan,
  boo#1089340)
* Wed Oct 17 2018 jsegitz@suse.com
- whitelist systemd-timesyncd (bsc#1111254)
* Tue Oct 16 2018 opensuse-packaging@opensuse.org
- Update rpmlint-checks to version master:
  * Use only one pattern that covers both cases
  * Add support to identify tmpfiles_create used with just a basename
* Mon Oct  8 2018 opensuse-packaging@opensuse.org
- Update to version master:
  * security checks: add link to openSUSE wiki to error message details
* Fri Oct  5 2018 matthias.gerstner@suse.com
- whitelist NetworkManager-fortisslvpn (bsc#1109938)
* Mon Sep 24 2018 matthias.gerstner@suse.com
- whitelist iwd D-Bus service (bsc#1108037)
* Wed Sep 12 2018 mpost@suse.com
- Add new zkeyadm group
* Mon Sep  3 2018 mchandras@suse.de
- Add new firejail group
* Mon Aug 20 2018 matthias.gerstner@suse.com
- whitelist xpra D-Bus service (bsc#1102836)
* Wed Aug  8 2018 lnussel@suse.de
- adjust maximum valid suse_version to 1550 (boo#1104110)
* Fri Jul 20 2018 matthias.gerstner@suse.com
- whitelist ratbagd D-Bus service (bsc#1076467)
* Thu Jul 12 2018 dmueller@suse.com
- remove unnecessary suse-check-optional-dependencies.diff
- drop CheckBuildDate - does not produce hits and is
  relatively slow
* Wed Jul 11 2018 dmueller@suse.com
- add suse-rpmlint-all-pie.patch: refresh to handle the pie-executable
  case (rename from rpmlint-all-pie.patch)
* Mon Jul  9 2018 dmueller@suse.com
- drop obsolete suse-no-run-ldconfig.diff,
  suse-manpages-for-rc-scripts.diff
* Thu Jul  5 2018 matthias.gerstner@suse.com
- whitelist pam_oath PAM module after audit (bsc#1089114)
* Tue Jul  3 2018 mcepl@suse.com
- Add update-magic-values-python-37.patch
    Neccessary for update of Python to 3.7
    https://github.com/rpm-software-management/rpmlint/commit/52b715763217
* Tue Jul  3 2018 opensuse-packaging@opensuse.org
- Update rpmlint-checks to version master:
  * New file 5.33 does identify pie executables now (bsc#1097339)
- add 0001-Fix-compatibility-with-file-5.33.patch
* Mon Jul  2 2018 c.schweingruber@catatec.ch
- Add 'sogo' user and group (used in server:SOGo)
* Mon Jun 11 2018 matthias.gerstner@suse.com
- whitelisting NetworkManager-libreswan plugin (bnc#1089340)
* Mon Jun  4 2018 dmueller@suse.com
- add Lua/NodeJS related groups to list of valid groups (bsc#1095769)
* Mon Jun  4 2018 opensuse-packaging@opensuse.org
- Update rpmlint-checks to version master:
  * Blacklist python test folder in python packages
  * Error out on /etc/bash_completion.d in packages
  * Do not use otherproviders() SUSEism
* Wed May 16 2018 andy@onthewings.net
- Add Development/Languages/OCaml group.
* Fri May  4 2018 okurz@suse.com
- Add 'synapse' user and group.
* Wed May  2 2018 mchandras@suse.de
- Add 'openvswitch' user and group.
* Thu Apr 19 2018 matthias.gerstner@suse.com
- whitelisting pam_yubico module (bsc#1087060)
* Tue Apr 10 2018 matthias.gerstner@suse.com
- adding new names for kalarm DBUS service (bsc#1087714)
* Sun Apr  1 2018 novell@chromanet.de
- added bacula user and group.
* Thu Mar 22 2018 sleep_walker@opensuse.org
- Add tox user and toxcmd group as standard openSUSE GID and UID
* Fri Mar  9 2018 matthias.gerstner@suse.com
- Corrected tpm2-abrmd (bnc#1049694). The D-Bus activation file is named
  differently than the configuration file.
* Tue Feb 20 2018 dimstar@opensuse.org
- Add one more deprecated license:
  + GPL-2.0-with-font-exception.
* Tue Feb 20 2018 coolo@suse.com
- allow more deprecated licenses to unbreak ring1+2
* Sun Feb 18 2018 dmueller@suse.com
- add 0001-Always-import-XDG-desktop-files-as-utf8.patch
* Thu Feb 15 2018 coolo@suse.com
- Allow some deprecated licenses that we would replace on commit
  (SPDX 2->SPDX 3 conversion)
* Thu Feb  8 2018 opensuse-packaging@opensuse.org
- Update rpmlint-checks to version master:
  * polkit: make untracked privileges also an error
* Thu Feb  8 2018 opensuse-packaging@opensuse.org
- Update rpmlint-checks to version master:
  * Support uppercase tag macros used by RPM 4.14
* Thu Feb  8 2018 opensuse-packaging@opensuse.org
- Update to version 84.87+git20180202.3df4ae7:
  * Add testcases for MenuXDGCheck.py
* Tue Jan 23 2018 dmueller@suse.com
- refresh for 0001-Improve-XDG-Menu-checks-stability.patch
  remove xdg-paths-update.diff (merged into other patch)
* Mon Jan 15 2018 krahmer@suse.com
- whitelisting usbauth (bsc#1066877)
* Sun Jan 14 2018 ngompa13@gmail.com
- Add Development/{Languages,Libraries}/Rust groups as noted in wiki
* Wed Jan  3 2018 adam.majer@suse.de
- add missing comma (,) to config file
- add user/group _nsd for NSD name server
* Sat Dec  2 2017 stefan.bruens@rwth-aachen.de
- add 0001-Binariescheck-Check-for-chroot-chdir-on-ARM-PPC.patch
* Wed Nov 29 2017 krahmer@suse.com
- whitelisting kcmsddm (bsc#1065563)
* Fri Nov 24 2017 opensuse-packaging@opensuse.org
- Update to version master:
  * Fix warnings
  * Add new rpmlint check for new %%{_fillupdir} macro (boo#1069468)
  * Open paths within the rpm file itself
  * Fix python warning
  * BashismCheck: Only check regular files
  * Rewrite BashismsCheck to actually work
* Tue Nov 14 2017 dimstar@opensuse.org
- Add rpmlint-slpp-NUM-NUM.patch: Match libFOO<num>-<num> as a
  valid dependency on a libary. According the openSUSE packaging
  policy, if the library name ends on a number, we add a dash
  between the basename (before the .so) and the version after .so.
* Fri Nov  3 2017 opensuse-packaging@opensuse.org
- Update rpmlint-tests to version master:
  * Add Flake8 travis check
  * Fix scriptprog invocation
  * Print the duplicated filenames sorted to be stable accross multiple calls
* Wed Nov  1 2017 dmueller@suse.com
- add 0001-Avoid-calling-close-on-undefined-fd-variable.patch
* Tue Oct 24 2017 jengelh@inai.de
- Description updates. Use the %%make_install macro.
* Tue Oct 24 2017 dmueller@suse.com
- update suse-whitelist-opensuse.diff to avoid a false positive
* Tue Oct 24 2017 krahmer@suse.com
- adding connman (bsc#1057697)
* Sat Oct 21 2017 dmueller@suse.com
- add 0001-Accept-python-abi-as-a-valid-versioned-python-depend.patch
* Mon Oct 16 2017 dmueller@suse.com
- refresh 0001-Improve-XDG-Menu-checks-stability.patch (bsc#1063371)
* Wed Oct 11 2017 opensuse-packaging@opensuse.org
- Update to version master:
  * Python 3.x porting of the ErlangCheck
* Wed Oct 11 2017 opensuse-packaging@opensuse.org
- Update to version master:
  * Treat strongly versioned libs also as compliant (bsc#723726)
  * LibraryPolicy: allow %%%%_licensedir in packages (used by %%license)
- Hide the noisy warnings
* Tue Oct 10 2017 dmueller@suse.com
- add 0001-Avoid-false-positives-on-is_elf-check.patch (bsc#1057216)
  add 0007-Validate-Appdata-also-when-appstream-util-is-unavail.patch
- Update rpmlint-checks to version master:
  * Fix false positives for -theme- -> -branding- rename
  * Stop leaking filedescriptors
  * Pythonic fixes
  * Drop CheckAppdata (there is AppDataCheck upstream)
  * Tighten ELF check
  * Tiny code formatting cleanup
  * Tighten the branding policy reporting a bit to make it less confusing
* Fri Oct  6 2017 lnussel@suse.de
- add package groups from
  https://en.opensuse.org/openSUSE:Package_group_guidelines to enable the
  groups check
* Fri Sep 29 2017 dmueller@suse.com
- Update rpmlint-checks:
  * Flake8 fixes
  * Properly anchor systemd path checks
  * Python 3.x porting
  * Add TmpFilesCheck
  * Flake8 / Stop leaking filedescriptors
  * Port LibraryPolicyCheck to Python 3.x
- Update rpmlint-tests:
  * Stop leaking filedescriptors
  * Address various deprecation warnings
  * Avoid leaking fds and further Python 3.x porting
* Thu Sep 28 2017 dmueller@suse.com
- update to 1.10:
  * test: Skip fedoradev GPG checks at least for now
  * test: Refresh fedora* packages on image build
  * test: Use assertEqual where appropriate, thanks to flake8/hacking
  * test: Update fedora24 config to fedora26, run it on Travis
  * Add a new test for tmpfiles.d snippets in the /etc/ tree.
  * Add new tests for systemd units and udev rules in /etc/ tree
  * test: Disable hacking for now until it's flake8 3.4+ compatible
  * test: Set up flake8-bugbear, enable it in fedoradev container
  * rpmlint: Avoid unused loop control variable
  * ZipCheck: Add TODO
  * *: Avoid mutable argument defaults
  * Be aware of -debugsource packages
  * rpmdiff: Fix unused variable from previous commit
  * rpmdiff: Support soft dependencies
  * BinariesCheck, FilesCheck: Ignore various .build-id dirs
  * Add python3-devel and rpm-build to fedoradev container to provoke some issues
  * BinariesCheck: Popen env consistency fix
  * Pkg.getstatusoutput: Set LC_ALL for all Popens, defaulting to C
  * rpmlint: Fix checking specfile from stdin
  * test.sh: Extract rpmlint command to run_rpmlint
  * Revert "Remove unused spec_lines check_spec argument"
  * BinariesCheck: Trivial cleanups
  * travis: Run make install too
  * FilesCheck: Allow multiple bytecode magic values per Python version
  * tests: Make output test tools easier to reuse
  * FilesCheck: hg.python.org -> github.com/python
  * Pkg: Return vendor and distribution as unicode strings
  * FilesCheck: Add Python 3.7 bytecode magic value
  * Pkg.b2s: Add some more test cases
  * Pkg.b2s: Pass through str as-is on Python 3
  * TagsCheck.py: accept SPDX "and" and "or" operators in all-uppercase spelling
  * rb'foo' is not supported in Python 2, use br'foo' instead
  * travis: Enable centos6
  * Avoid Python 3.6 invalid esc seq warnings, use more raw strings
  * flake8 fixes
  * SpecCheck: Detect patches applied with "patch <" and "patch -i"
  * add /usr/lib/systemd to DEFAULT_HARDCODED_LIB_PATH_EXCEPTIONS (#93)
  * SpecCheck: Do not demand versioned filename Provides/Obsoletes
  * FilesCheck: Update Python 3.6 bytecode magic value again
  * Config: Fix flake8 3.2 / pycodestyle 2.2 errors (closes #82)
  * *: Fix various low hanging issues flagged by pycodestyle 2.1.0 (#82)
  * test.sh: Output flake8 --version
  * rpmdiff.1: update Arturo Borrero Gonzalez email address
  * FilesCheck: Update Python 3.6 bytecode magic value
  * Skip chroot-without-chdir check on non-x86_64
  * shlib-with-non-pic-code: add text on how to figure files compiled without -fPIC (#79)
  * *: Move indentation etc settings to .editorconfig
  * AbstractCheck: Close urllib responses explicitly also on error
  * tests: Switch Travis tests to Docker
  * Use importlib to load checks where available
  * FilesCheck: Use os.devnull
  * Testing: Avoid ResourceWarning on config read
  * Run tests with warnings on
  * Ignore negative returncode after SIGPIPE caused by closing on purpose
  * Fix last commit
  * Use default bufsize, move regex compile to common place
  * BinariesCheck: lower memory requirements, fix chroot/chdir detection
  * FilesCheck: Avoid crash accessing non-ASCII filenames in some cases
  * Filter: More non-ASCII print fixing, including in e.g. C locale
  * SpecCheck: Output spec basename, not tempfile when checking srpm
  * Cleanups
  * FilesCheck: Update Python 3.5 and 3.6 bytecode magic values
  * test: Test for unexpected errors in default and C locales
  * Remove obsolete LC_ALL setting from Makefile
- drop version-control-internal-file.diff, boo1027577-license_tag.patch,
    add-weak-dependencies.diff: upstream
- drop sourced-dirs.diff, fix-shared-library-matching.diff,
    suse-python-abi-check.diff, add-check-for-tmpfiles-created-at-r.diff: obsolete
- drop suse-readd_terminator_in_regex.patch: merged into original patch
- add suse-tests-without-badness.patch,
    0001-Extend-scm_regex-to-capture-more-SCM-system-files.patch,
    0003-Tighten-lib_regex-to-avoid-false-positive-in-python-.patch,
    0001-Execute-chroot-tests-also-on-x86-rpms.patch,
    ignore-readelf-ar-error.diff, remove-ghostfile-checks.diff,
    fix-diag-sortorder.diff, drop-unicodedata-dep.diff,
    0001-Tighten-wrong-script-interpreter-check-to-lower-fals.patch,
    0001-Improve-XDG-Menu-checks-stability.patch,
    0001-split-wrong-script-interpreter-into-env-script-inter.patch,
    0001-Handle-post-scripts-that-contain-non-ascii-character.patch
- drop config.in: unused
- switch to python 3.x
* Thu Sep 28 2017 dmueller@suse.com
- update to 1.9:
  * Pkg: Fix magic.descriptor availability check
  * warn: Define only once, with print_function
  * FilesCheck: Check for *.gir in devel, *.typelib in non-devel, fixes #74
  * FilesCheck: Improve devel-file-in-non-devel-package description
  * flake8: Ignore H105
  * Makefile: Remove generate-isocodes dep from __isocodes__
  * __isocodes__: Regenerate
  * generate-isocodes: Switch to JSON source files (#72)
  * test.sh: Check man pages for warnings
  * Delete dead if-block
  * Filter: Line wrap cleanup
  * Filter: Use sys.version_info to check Python version
  * Fix octal string literals
  * Solve exceptions on printing str (Fixes #61)
  * tests: Add autofs binary rpm for testing non-ASCII output issues
  * test: Add some test packages containing non-UTF-8 filenames
  * BinariesCheck: avoid false chroot w/o chdir when objdump fails
  * flake8 fixes
  * rpmdiff: Import site only if needed
  * Testing: Add and use default for path to tests
  * FilesCheck: Update Python 3.6 bytecode magic value
  * FilesCheck: Fix regression in finding shebangs without arguments
  * Ignore .cache dir
  * Clean up Python < 2.6 cruft
  * Add hacking flake8 to Travis and ignores
  * flake8 fixes
  * Use new style classes
  * Run flake8 on rpmdiff and rpmlint too
  * Handle more file open/close with "with"
  * Exception handling cleanups
  * FilesCheck: Look for shebang only at start of file
  * travis: python3-rpm doesn't exist even for Trusty, so can't test with 3.4
  * travis: Switch to Ubuntu Trusty, test with Python 2.7 and 3.4
  * Use Travis apt addon for whitelisted packages
  * Test import order
  * Sort imports per PEP8, Google Python Style Guide
  * Add Python 3.6 magic value
  * Fix resolving Python source from 3.5 *.opt-[12].pyc
  * Move most Emacs settings to .dir-locals.el
  * Add %%python2_sitearch and %%python3_sitearch to private SO paths
  * Prevent empty paths from entering private SO paths
  * remove files-attr-not-set check
  * Expand postin/postun once per pkg instead once per file
  * Install rpm in travis for signature check
  * Avoid running some regexps
  * Run flake8 in test suite
  * flake8 fixes
  * make test suite fail on more errors
  * Comment update
  * Note and test libmagic >= 5.05 dep
  * Fix magic processing for Python 3
  * Mimic magic closer for symbolic links
  * Workaround slowness due to python-magic bug
  * Shortcut file magic, derive from file mode
  * Spelling fix
  * Unbreak create_*regex_call now that lines are shortened by call_regex
  * Drop unnecessary symbol_table_regex
  * Avoid false function call vs definition positives, thanks to Stefan Bruens
  * pep8 fixes
  * Add some pep8 settings
  * Split parsing of readelf output into header and symbols part
  * Skip checks for problematic function calls if common prefix does not match
  * Use shlex.quote for better shell escaping where available
  * TODO update
  * Don't limit build badge to master branch
  * Convert README to markdown
  * Travis: install rpm2cpio
  * +TODO
  * Travis: Use Python 2.7 and system site packages
  * Travis: try pytest from pip instead of apt-get
  * Initial travis setup
  * Include interpreter arguments in output messages for filtering control
  * Flag /usr/bin/env as a wrong interpreter
- drop rpmlint-pkg-quoting.diff, suse-g-ir-chech.diff, remove-expand-macros.diff,
  remove-files-attr-not-set-check.diff, postin-speedup.diff, binaryinfo-speedup.diff,
  0001-Fix-resolving-Python-source-from-3.5-.opt-12.pyc.patch,
  issue_68_BinariesCheck_lower_memory-1.patch, issue_68_BinariesCheck_lower_memory-2.patch,
  issue_68_BinariesCheck_lower_memory-3.patch, issue_68_BinariesCheck_lower_memory-4.patch,
  BinariesCheck_fix_chroot_check_on_non_x86.patch: either upstreamed as is or slightly different
- drop suse-sysv-init-checks.diff, 0001-Avoid-messing-with-the-error-encoding-Fixes-61.patch,
  suse-filesystem.diff, script-interpreter-only-for-exec-sc.diff: obsolete
- drop update_git.sh related stuff: this is obsolete, patches are
  either supposed to be upstreamed or handled via quilt
- add suse-skip-macro-expansion.diff: rename from remove-expand-macros.diff
* Thu Sep 28 2017 opensuse-packaging@opensuse.org
- Update to version master:
  * Ignore trailing whitespace in permission files (bsc#1060738)
* Fri Sep 22 2017 eich@suse.com
- Add group 'singularity' for package singularity
  (See network:cluster/singularity) (FATE#323048).
* Wed Sep 20 2017 daniel.molkentin@suse.com
- Add dehydrated user & group for dehydrated, a letsencrypt client
  FATE#323377
* Wed Sep  6 2017 krahmer@suse.com
- Adding fwupd (bsc#932807)
* Tue Aug 15 2017 bliu@suse.com
-  add coroqnetd for corosync-qnetd to rpmlint
* Mon Aug 14 2017 matthias.gerstner@suse.com
- Adding NetworkManager-l2tp (bsc#846337)
* Mon Aug 14 2017 matthias.gerstner@suse.com
- Adding pam_script (bsc#1039848)
* Tue Aug  8 2017 krahmer@suse.com
- Adding nfs-ganesha (bsc#997880)
* Tue Jul 25 2017 matthias.gerstner@suse.com
- Added tpm2-abrmd (bnc#1049694)
* Sat Jul 15 2017 ilya@ilya.pp.ua
- Add user mednafen for mednafen network play server
* Tue Jul 11 2017 krahmer@suse.com
- Adding pam_dbus (bsc#1039709)
* Thu Jun 22 2017 meissner@suse.com
- rpmlint-all-pie.patch: for non-PIE built binaries emit a warning
  to suggest build them as PIE.
* Tue Jun  6 2017 marec@detebe.org
- std-user and std-group 'bitcoin' added for building correct bitcoin daemon
* Thu Jun  1 2017 stefan.bruens@rwth-aachen.de
- Add BinariesCheck_fix_chroot_check_on_non_x86.patch
  Check for correct invocation of chroot was only implemented for x86
* Wed May 31 2017 jochen.becker@hrz.tu-darmstadt.de
- std-user and std-group 'xymon', added for building correct xymon client
* Wed May 31 2017 krahmer@suse.com
- whitelisting openqa (bsc#1039290)
* Thu May 25 2017 tserong@suse.com
- add 'prometheus' and 'grafana' standard users and groups
* Tue May 16 2017 krahmer@suse.com
- whitelisting switchroo-control (bsc#1034309)
* Fri Apr 28 2017 mgerstner@suse.com
- whitelisting backintime (bsc#1007723, bsc#1032717)
* Wed Apr 19 2017 krahmer@suse.com
- whitelisting thunderbolt (bsc#1033554)
* Tue Apr 18 2017 opensuse-packaging@opensuse.org
- Update to version master:
  * remote unused/outdated checks
* Tue Apr 18 2017 opensuse-packaging@opensuse.org
- Update to version 84.87+git20170418.092177d:
  * Remove initscript related tests, systemd FTW!
* Tue Apr 11 2017 mgerstner@suse.com
- Adding kwalletmanager5 (bsc#1033296)
* Tue Apr 11 2017 krahmer@suse.com
- Adding os-autoinst (bsc#1032649)
* Mon Apr 10 2017 dmueller@suse.com
- remove CheckKDE4Deps, CheckInitScripts
* Mon Mar 20 2017 lnussel@suse.de
- actually enable CheckSysVinitOnSystemd
* Fri Mar 17 2017 kkaempf@suse.com
- Add logstash to StandardGroups and StandardUsers.
* Thu Mar  9 2017 lnussel@suse.de
- rpmlint-checks:
  * Check for old SysVinit scripts and the usage of insserv (FATE#322953)
  * Prevent a false-positive in systemd
* Thu Mar  2 2017 mimi.vx@gmail.com
- fix boo#1027577
  patch boo1027577-license_tag.patch
* Mon Feb  6 2017 lars@linux-schulserver.de
- rename user/group sks to _sks following
  https://github.com/LinuxStandardBase/lsb/pull/21
* Mon Feb  6 2017 krahmer@suse.com
- adding blueman (bsc#987141)
* Tue Jan 31 2017 zaitor@opensuse.org
- Add gdm to StandardGroups.
- Add polkitd to StandardUsers.
* Tue Jan 31 2017 meissner@suse.com
- suse-spdx-license-exceptions.patch: removed fuzziness from patch.
- issue_68_BinariesCheck_lower_memory.patch: split into seperate patches
  issue_68_BinariesCheck_lower_memory-1.patch
  issue_68_BinariesCheck_lower_memory-2.patch
  issue_68_BinariesCheck_lower_memory-3.patch
  issue_68_BinariesCheck_lower_memory-4.patch
  and unfuzzed patch number 3.
* Tue Jan 31 2017 krahmer@suse.com
- Whitelisting rebootmgr (bsc#1019644)
* Tue Jan 24 2017 krahmer@suse.com
- Whitelisting powerdevil discretegpuhelper (bsc#1019748)
* Mon Jan  9 2017 krahmer@suse.com
- Adding org.freedesktop.resolve1.conf (bsc#917781)
* Tue Jan  3 2017 stefan.bruens@rwth-aachen.de
- add suse-readd_terminator_in_regex.patch
  Fixes bad detection of dependencies for devel packages
* Mon Jan  2 2017 dmueller@suse.com
- update suse-obsolete-version check (bsc#743981)
* Mon Dec  5 2016 krahmer@suse.com
- whitelisting pam_slurm (bsc#1007053)
* Wed Oct 26 2016 krahmer@suse.com
- whitelisting pam_gdm (bsc#1004346)
* Tue Oct 11 2016 meissner@suse.com
- config: whitelist flatpak dbus service/config (bsc#984817)
* Wed Sep 14 2016 krahmer@suse.com
- adding sysprof DBUS service (bsc#996111)
* Tue Sep  6 2016 lars@linux-schulserver.de
- Adding sks (Synchronizing Key Server) to known user/group
* Tue Sep  6 2016 lnussel@suse.de
- rpmlint-checks:
  * Make checks python3 compatible
  * Fix update-alternatives check when it's quoted
* Fri Aug 19 2016 stefan.bruens@rwth-aachen.de
- Update some checks to work on both Python 2 and 3
* Mon Jul 25 2016 lnussel@suse.de
- rpmlint-checks:
  * Fix typo in BrandingPolicyCheck.py
* Thu Jun 30 2016 stefan.bruens@rwth-aachen.de
- Add issue_68_BinariesCheck_lower_memory.patch
  Fixes out-of-memory errors on 32bit systems (bsc#969732)
* Fri Jun 17 2016 mvetter@suse.com
- Adding prosody to known user/group
* Fri May 27 2016 alarrosa@suse.com
- add 0001-Fix-resolving-Python-source-from-3.5-.opt-12.pyc.patch:
  Fixes FilesCheck to resolve correctly the python source file
  from pyc files following PEP0488 (like *.{tag}.opt-[12].pyc).
  (bsc#982076)
* Thu May 19 2016 dmueller@suse.com
- suse-spdx-license-exceptions.patch, suse-sysv-init-checks.diff:
  adjust to match rpmlint-tests again
* Thu May 19 2016 dmueller@suse.com
- update link to list of valid licenses
* Thu May 19 2016 meissner@suse.com
- temporary approval for tcmu-runner dbus service (bsc#978903)
* Tue May  3 2016 stefan.bruens@rwth-aachen.de
- add omit_BUILDROOT_from_pyo_files.patch (boo#978306)
* Wed Apr  6 2016 dmueller@suse.com
- add suse-spdx-license-exceptions.patch (bsc#973404)
* Wed Mar 30 2016 krahmer@suse.com
- whitelisting openattic (bsc#972478)
* Thu Mar 24 2016 mpost@suse.com
- Updated config file to add user chrony and group chrony
  (Fate#319508)
* Mon Mar 14 2016 christoph@stop.pe
- whitelist rabbitmq user and group
* Tue Mar  8 2016 stefan.bruens@rwth-aachen.de
- Fix boo#970170: rpmlint no longer detects gethostbyname calls,
  also detect gethostbyname{,2}{,_r}, gethostbyaddr{,_r}
  * update suse-binariescheck.diff
  * rpmlint-check-gethostbyname.patch
* Mon Feb 22 2016 dmueller@suse.com
- add 0001-Avoid-messing-with-the-error-encoding-Fixes-61.patch (bsc#967556)
- fix requires
* Fri Feb 12 2016 sleep_walker@opensuse.org
- add 'guixbuild' as standard group
- don't require %%config for bash completion scripts in /etc
* Thu Feb  4 2016 lnussel@suse.de
- whitelist systemd-importd (bnc#964935)
* Thu Jan 28 2016 dmueller@suse.com
- enable tests during building
* Thu Jan 21 2016 dmueller@suse.com
- add postin-speedup.diff, binaryinfo-speedup.diff
* Wed Jan 20 2016 krahmer@suse.com
- whitelist iio-sensor-proxy (bsc#939191)
* Wed Jan 13 2016 krahmer@suse.com
- whitelist drbdmanage DBUS (bsc#956811)
* Fri Dec 11 2015 astieger@suse.com
- add wireshark group [bsc#957624]
* Tue Dec  1 2015 krahmer@suse.com
- adding thermald DBUS service (bsc#954771)
* Mon Nov 30 2015 lnussel@suse.de
- fix shared library matching (fix-shared-library-matching.diff)
* Fri Nov 13 2015 lnussel@suse.de
- rpmlint 1.8 update
  * python 3 fixes
  * Add support for file triggers
  * Mechanism to black list certain C calls
  * new error: non-devel-file-in-devel-package
  * appdata check configurable
  * project moved to github
  * Patches dropped:
  avoid-mismatched-libregex.diff
  filename-non-utf8-exception.diff
  fix-ghost-file-handling.diff
  save-content-to-an-array.diff
  fix-TmpFilesCheck-pattern-match.diff
  move-ghost-file-check-to-TmpFilesCh.diff
* Fri Nov 13 2015 lnussel@suse.de
- fix TmpFilesCheck not finding pattern in the full script
  (fix-TmpFilesCheck-pattern-match.diff)
* Mon Nov  9 2015 krahmer@suse.com
- whitelisting cinnamon settings daemon (bsc#951830)
* Wed Oct 14 2015 lnussel@suse.de
- Speedup CheckBuildDate check
- add _service file snippet for rpmlint-checks and regenerate from git
* Fri Sep 11 2015 aboe76@gmail.com
- Added salt user and group (bnc#939831)
* Wed Sep  9 2015 krahmer@suse.com
- Added teamd DBUS config (bnc#941993)
* Tue Sep  8 2015 kstreitova@suse.com
- Add shibd user and group [fate#318304]
* Thu Jul  9 2015 msrb@suse.com
- Add vnc user and group. (fate#318936)
* Tue Jun 30 2015 meissner@suse.com
- add a whitespace line as %%autosetup seems broken.
* Wed Jun 24 2015 tchvatal@suse.com
- Add mysql group to the known groups
* Wed May 20 2015 lnussel@suse.de
- skip files handled by tmpfile mechnism in regular ghost file check
  (move-ghost-file-check-to-TmpFilesCh.diff)
* Tue May 19 2015 lnussel@suse.de
- fix update_git.sh
- make sure tmpfiles are listed in %%files
  (add-check-for-tmpfiles-created-at-r.diff)
- don't complain about missingok ghost files
  (fix-ghost-file-handling.diff)
- remove obsolete check for %%defattr in spec files
  (remove-files-attr-not-set-check.diff)
* Fri Apr 24 2015 tserong@suse.com
- added standard user and group ceph (bnc#928492)
* Wed Apr 22 2015 krahmer@suse.com
- fixing some .conf/.service suffixes
* Wed Apr 22 2015 krahmer@suse.com
- adding realmd DBUS service (bnc#916766)
* Mon Apr 20 2015 lnussel@suse.de
- update save-content-to-an-array.diff with upstream version
* Fri Apr 10 2015 lnussel@suse.de
- new versioin 1.6
- add script update_git.sh based on qemu's to simplify importing
  a patch series from git after rebasing.
  * Patches dropped:
  0001-Python-3-compatibility-tweaks.patch (upstream)
  0001-Set-Python-3.4-magic-number-to-3310.patch (upstream)
  add-scoring-support.diff (different upstream solution)
  check-buildroot-during-install.diff (need to fix no-cleaning-of-buildroot check upstream)
  fix-versioned-prereq.diff (was disabled, not sure what it's useful for)
  ignore-non-readable-in-etc.diff (filtered anyways)
  locale-support.diff (drop)
  locale-update.diff (different upstream solution now)
  more-verbose-lsb-check.diff (drop)
  perl-versioned-rpath-deps.diff (upstream)
  rpmlint-1.5-disallow-var-run-and-var-lock.diff (upstream)
  rpmlint-1.5-Fix-setgroups-error-name.diff (upstream)
  rpmlint-decode-fix.diff (different upstream solution)
  rpmlint-fix-unexpanded-macros-for-array-values.patch (different upstream solution)
  stricter-tags-check.diff (merged in weak deps and check-for-self-provides.diff)
  suppress-for-perl-python.diff (use filter instead)
  suse-binary-info-compile-opts.diff (drop)
  suse-changelog.patch (change config instead)
  suse-mono-deps-checks.diff (useful?)
  suse-required-lsb-tags.diff (different upstream solution)
  verify-buildrequires.diff (very build system specific, drop)
  xdg-check-exception.diff (upstream)
  * renamed patches:
  script-interpreter-only-for-exec-scripts.diff
  - > script-interpreter-only-for-exec-sc.diff
  confusing-invalid-spec-name.patch
  - > confusing-invalid-spec-name.diff
  suse-manpages-for-rc-scripts.patch
  - > suse-manpages-for-rc-scripts.diff
  sysv5-init-checks.diff
  - > suse-sysv-init-checks.diff
  * added patches:
  check-for-self-provides.diff
  save-content-to-an-array.diff
* Thu Apr  9 2015 meissner@suse.com
- use the correct networkd dbus service names. (bnc#918799)
* Mon Mar  9 2015 krahmer@suse.com
- added systemd network DBUS service (bnc#918799)
* Wed Feb 11 2015 krahmer@suse.com
- added storaged DBUS service (bnc#915769)
* Tue Feb 10 2015 kkaempf@suse.com
- add standard users and groups pcp and pcpqa for pcp
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- whitelist sddm (boo#897788)
* Wed Dec 10 2014 krahmer@suse.com
- added firewalld dbus service (bnc#907625)
* Wed Dec  3 2014 krahmer@suse.com
- added iouyap group (bnc#904060)
* Mon Dec  1 2014 jmatejek@suse.com
- added standard user and group davfs2 (bnc#907662, FATE#318116)
* Mon Oct 27 2014 tboerger@suse.com
- Added standard user and group crowbar for crowbar systemmanagement
* Wed Sep 24 2014 sfalken@opensuse.org
- added standard user and group siproxd for the siproxd proxy
* Wed Aug 27 2014 wagner-thomas@gmx.at
- added standard user iodined for the iodine DNS tunnel daemon
* Fri Aug 22 2014 nwang@suse.com
- FATE#314409. Add libstoragemgmt user/group.
* Thu Aug 21 2014 hrvoje.senjan@gmail.com
- Add sddm user/group
* Thu Aug 21 2014 wagner-thomas@gmx.at
- Added standard user/group polipo
* Thu Aug 21 2014 darin@darins.net
- Add user/group unbound for unbound caching dns server
* Thu Aug 21 2014 lnussel@suse.de
- adjust initscript check to match new systemctl based
  %%restart_on_update resp %%stop_on_removal
* Mon Jul 21 2014 werner@suse.de
- Add the groups systemd-journal, systemd-journal-gateway, and tape
  as required by systemd
- Add the user systemd-journal-gateway as required by systemd
* Fri Jul 18 2014 jsegitz@suse.com
- updated rpmlint-checks-master.tar.gz to include CheckSystemdInstall.py
* Thu Jul 17 2014 meissner@suse.com
- allow org.kde.kf5auth.conf after adjustment of race condition
  (bnc#864716)
* Tue Jul  8 2014 achernikov@suse.com
- added user and group sensu required for sensu server, client
* Tue Jul  1 2014 meissner@suse.com
- allow user and group ddclient for the ddclient users (bnc#881520)
* Fri Jun 20 2014 meissner@suse.com
- allow user bitlbee for the bitlbee irc server.
* Wed Jun 11 2014 krahmer@suse.com
- enable oFono DBUS for SLE12 (bnc#862354)
* Mon May 19 2014 meissner@suse.com
- enable org.selinux.service and org.selinux.conf of policycoreutils
  (pending more review) bnc#878631
* Thu May  8 2014 dmueller@suse.com
- add 0001-Set-Python-3.4-magic-number-to-3310.patch (bnc#876470)
* Tue May  6 2014 lnussel@suse.de
- dd filter expections for filesystem package
* Mon May  5 2014 lnussel@suse.de
- disallow /var/run and /var/lock
  (rpmlint-1.5-disallow-var-run-and-var-lock.diff)
* Fri Apr 25 2014 evilissimo@redhat.com
- adding ovirtagent standard user and standard group names (uid/gid 175)
* Tue Apr 22 2014 krahmer@suse.com
- adding baloo DBUS service file (missing in last request) (bnc#866131)
* Wed Apr 16 2014 krahmer@suse.com
- adding baloo DBUS config, formerly nepomuk (bnc#866131)
* Fri Apr  4 2014 lnussel@suse.de
- allow /run (bnc#870190)
* Wed Apr  2 2014 dmueller@suse.com
- update KMPPolicycheck
* Sat Mar 29 2014 chris@computersalat.de
- added group 'squid' for squid
* Wed Mar 26 2014 chris@computersalat.de
- added user, group 'boinc' for boinc-client
* Tue Mar 18 2014 meissner@suse.com
- allow org.freedesktop.GeoClue2.Agent.conf (bnc#862216)
* Wed Mar  5 2014 lnussel@suse.de
- add minimal check to verify appdata.xml files are parsable XML
* Thu Feb 27 2014 aplanas@suse.com
- added patches:
  * rpmlint-fix-unexpanded-macros-for-array-values.patch
- fix _unexpanded_macros for array values
* Thu Feb 27 2014 lnussel@suse.de
- rip out all decode in an attempt to make it work
- modified patches:
  * rpmlint-decode-fix.diff
* Thu Feb 27 2014 aplanas@suse.com
- added paches:
  * rpmlint-decode-fix.diff
- Fix decode from UTF-8 string in Python 2
* Sun Feb 23 2014 schwab@suse.de
- usr-arch.diff: update usr_arch_share_regex
* Fri Feb 21 2014 mls@suse.de
- adapt to new rpm weak dependency tags
* Fri Feb 21 2014 dmueller@suse.com
- added patches:
  * 0001-Python-3-compatibility-tweaks.patch
- Change openstack- related users to non-prefixed variants,
  as they get renamed with the switch to Icehouse
* Mon Feb 10 2014 krahmer@suse.com
- whitelisting networkmanager-openswan (bnc#808549)
* Thu Jan 30 2014 lnussel@suse.de
- remove suse-rclink-check.diff and implement as separate check for
  systemd units instead (bnc#860340).
* Tue Jan 28 2014 mpost@suse.com
- Added group 'ts-shell' for terminal server
* Wed Nov 27 2013 krahmer@suse.com
- Whitelisting NFC neard DBUS service (bnc#837978)
* Wed Nov 20 2013 f.celler@triagens.de
- Add user and group 'arangodb' for ArangoDB database server
* Wed Nov 20 2013 krahmer@suse.com
- Whitelisting kwallet DBUS service (bnc#849739)
* Tue Nov 19 2013 krahmer@suse.com
- Whitelisting bluez DBUS service (bnc#768062)
* Mon Nov 18 2013 krahmer@suse.com
- Adding org.selinux DBUS service (bnc#848550)
* Wed Oct 23 2013 heinemannj66@gmail.com
- Add 'elasticsearch' to standard users and groups
  * package: elasticsearch
  * Summary: Open Source, Distributed, RESTful Search Engine
  * URL: http://www.elasticsearch.org
  * License: Apache-2.0
  * systemd elasticsearch.service needs
    LimitNOFILE=65535
    LimitMEMLOCK=infinity
    for user and group elasticsearch
* Tue Oct 15 2013 krahmer@suse.com
- Whitelisting com.redhat.tuned DBUS service (bnc#787379)
* Mon Sep 30 2013 dmueller@suse.com
- Sync checks with git (FATE#316521)
* Wed Sep 25 2013 meissner@suse.com
- whitelist second iteration of wicked dbus service names
  (bnc#783932)
* Mon Sep 23 2013 dmueller@suse.com
- blacklist old systemd/udev directories (bnc#816467)
- remove checking for groups (bnc#767551)
- ignore icon size mismatches on animated icons (bnc#480664)
- update obsolete/invalid suse version check
* Tue Sep 17 2013 abergmann@suse.com
- whitelisted mate DBUS Service (bnc#831404)
* Sat Sep 14 2013 matwey.kornilov@gmail.com
- add requirement for ErlangCheck.py (pull request #2)
* Wed Sep 11 2013 abergmann@suse.de
- whitelisted GeoClue2 DBUS Service (bnc#838360)
* Wed Aug 28 2013 meissner@suse.com
- allow pam_mate_keyring (same to gnome keyring) (bnc#831404)
* Fri Aug  9 2013 dmueller@suse.com
- update rpmlint-checks from git
* Wed Aug  7 2013 dmueller@suse.com
- add suse-ignore-specfile-errors.diff:
  ignore specfile-errors
* Tue Aug  6 2013 dmueller@suse.com
- add xdg-check-exception.diff:
  handle xdg menu files without exec entry (bnc#833384)
* Wed Jul 31 2013 meissner@suse.com
- allow pam_snapper after audit (bnc#815383)
* Tue Jul 30 2013 meissner@suse.com
- follow /usr move for the /bin/ binaries in pie.config.
* Tue Jul 30 2013 lnussel@suse.de
- fix setgroups error name, patch from upstream git:
  rpmlint-1.5-Fix-setgroups-error-name.diff
* Mon Jul 29 2013 meissner@suse.com
- allow systemd machined service as-is (bnc#828207)
* Tue Jul 23 2013 meissner@suse.com
- Allow current wicked DBUS services (bnc#783932)
* Thu Jul  4 2013 meissner@suse.com
- allow nepomuk helpers temporary without full audit (bnc#825262)
* Fri Jun 28 2013 dmueller@suse.com
- drop outdated Update-alternatives check (bnc#826993)
- add basic new update-alternatives check
* Fri Jun 21 2013 nkrinner@suse.com
- Add 'chef' to standard users and groups
* Tue Jun 11 2013 meissner@suse.com
- allowed kcm helper for lightdm-kde-greeter (bnc#794705)
* Mon Jun  3 2013 meissner@suse.com
- allow fprintd DBUS services (bnc#792095)
* Thu May 30 2013 tchvatal@suse.com
- Add group 'locate' for mlocate package
* Tue May 28 2013 dmueller@suse.com
- update to 1.5:
  * New Homepage
  * Plenty of new checks
- add compressed-backup-regex.diff
- remove python3_magic_number_fix.diff
* Mon May 20 2013 andreas.stieger@gmx.de
- Add user and group 'svn' for svnserve in package subversion
* Mon Apr 15 2013 meissner@suse.com
- add new ModemManager interface / service (bnc#798273)
* Tue Feb 26 2013 dmueller@suse.com
- add suse-filter-more-verbose.diff:
  * make it more obvious which rpmlintrc causes an exception (bnc#801192)
* Mon Feb 18 2013 meissner@suse.com
- allow nm-iodine-service.conf DBUS service (bnc#781071)
* Fri Feb  8 2013 matwey.kornilov@gmail.com
- Add user and group 'empd' for erlang
* Sat Feb  2 2013 archie@dellroad.org
- Add user 'fonehome' and group 'fonehome'
* Thu Jan 24 2013 aj@ajaissle.de
- Add Kolab users + groups
  * kolab (Kolab System Account / management)
  * kolab-n (Kolab System Account (N) / non-privileged)
  * kolab-r (Kolab System Account (R) / restricted)
* Wed Jan  2 2013 dmueller@suse.com
- fix incorrect branding require warnings
* Thu Dec 20 2012 lnussel@suse.de
- update check for %%run_permissions
* Fri Dec  7 2012 saschpe@suse.de
- Add suse-manpages-for-rc-scripts.patch: Don't complain about
  missing man-pages for rc-scripts
* Thu Nov 29 2012 dimstar@opensuse.org
- Add colord uid and gid.
* Fri Nov 23 2012 saschpe@suse.de
- Add additional OpenStack users/groups
* Fri Nov 16 2012 asterios.dramis@gmail.com
- Added a patch (python3_magic_number_fix.diff) to update the magic number for
  python 3 (patch taken from upstream).
* Wed Nov 14 2012 meissner@suse.com
- whitelist org.freedesktop.AutoMount.conf (bnc#782691),
  that wants to talk to udisks
* Mon Nov  5 2012 lnussel@suse.de
- add libopenal1 to legacy exceptions again. Got lost after the
  packaging changes apparently.
* Fri Oct 12 2012 meissner@suse.com
- allow snapper dbus service after audit (bnc#759391)
* Mon Oct  8 2012 coolo@suse.com
- no longer allow semicolon in licenses
* Thu Oct  4 2012 aj@suse.de
- Remove check for /var/lock and /var/run since it's in upstream
  rpmlint already.
* Wed Sep 26 2012 aj@suse.de
- Add README.packaging.txt to explain packaging of file
  rpmlint-checks-$VERSION.tar.gz
- Package all *py files into rpmlint-checks tarball
- Add _service file to update rpmlint-checks tarball
- Add /etc/systemd.d, /etc/modules-load.d and /etc/tmpfiles.d to the
  blacklist, only users should write here.
- Blacklist the directories used by systemd.
- Remove SuSEconfig directories (update patch suse-filesystem.diff)
- Add warnings about files on tmpfs in /var/lock or /var/run.
* Wed Sep 26 2012 dmueller@suse.com
- restore LibraryPolicy from git
* Sat Sep 15 2012 coolo@suse.com
- fix one more case of scripts progs changing types
* Thu Sep 13 2012 dmueller@suse.com
- update to 1.4:
  * rpmdiff: Teach rpmdiff about pretrans and posttrans
  * SpecCheck.py: merge patch from #97, using BuildArch with
  something else than Noarch is likely a error and causing issues.
  * FilesCheck.py: Add Python 3.3 magic number
  * FilesCheck.py, InitScriptCheck.py, MenuCheck.py, Pkg.py,
    PostCheck.py: Prepare for rpm-python possibly returning script
  progs as arrays.
* Fri Aug  3 2012 thardeck@suse.com
- added icinga users and groups
* Thu Jul  5 2012 dmueller@suse.com
- remove python naming check (bnc#768247)
* Tue Jun 26 2012 lnussel@suse.de
- add libopenal1 to legacy exceptions. It's a special case since the ABI for
  openal is defined in a standard and there can be multiple
  imlementations of the standard. Therefore it's necessary to have
  some kind of prefix or suffix for packages that contain libopenal1
* Thu Jun 21 2012 lnussel@suse.de
- add bluez dbus autolaunch stub (bnc#768062)
* Mon Jun 18 2012 saschpe@suse.de
- Add several OpenStack users/groups
* Mon Jun 18 2012 aj@suse.de
- Cleanup list of SuSEconfig scripts - remove non-existant entries.
* Tue Jun  5 2012 lnussel@suse.de
- remove tdb tools binaries, not needed for PIE (bnc#765476)
* Fri Jun  1 2012 lnussel@suse.de
- add cdemu-deamon to dbus white list (bnc#764063)
* Wed May 23 2012 lnussel@suse.de
- add check for pam modules (fate#313077)
* Tue May 15 2012 lnussel@suse.de
- add texlive.texlive to whitelist (bnc#762144)
* Mon May 14 2012 lnussel@suse.de
- add 'mktex' group as used by texlive
* Wed Mar 21 2012 dmueller@suse.de
- fix false positives for swp matching
* Tue Mar 20 2012 lnussel@suse.de
- better deal with spaces in logrotate config
- add colord-sane dbus service to whitelist (bnc#752518)
* Fri Mar 16 2012 dmueller@suse.de
- fix parsing of update-alternatives and clarify info message
* Tue Mar 13 2012 dmueller@suse.de
- block .swp files as well (they are usually vi(m) backup files)
* Wed Feb 29 2012 lnussel@suse.de
- add udisks2 to dbus whitelist (bnc#742751)
- add smb4k to dbus whitelist (bnc#749065)
* Wed Feb 29 2012 dmueller@suse.de
- ignore fixed dependencies on config()
* Mon Feb 20 2012 lnussel@suse.de
- add logrotate check (bnc#677335)
* Mon Feb 20 2012 lnussel@suse.de
- NetworkManager.conf was renamed to org.freedesktop.NetworkManager.conf (bnc#747780)
* Tue Jan 31 2012 lnussel@suse.de
- suse-filelist-empty is meant as warning only
* Thu Jan 26 2012 suse@ammler.ch
- add standard group and user znc (server:irc/znc)
* Wed Jan 11 2012 vcizek@suse.com
- added standard user and group "puppet"
* Wed Jan  4 2012 dmueller@suse.de
- reenable libtool wrapper check
* Wed Dec 21 2011 dmueller@suse.de
- unbreak config afer DesktopTranslationCheck was removed
* Fri Dec 16 2011 coolo@suse.com
- create the valid licenses from list tracked by SUSE legal (dumped
  into obs-service_format_spec_file, so use that one as buildrequire)
* Tue Dec 13 2011 andreas.stieger@gmx.de
- added: standard group 'tor'
- added: standard user 'tor'
* Tue Dec 13 2011 coolo@suse.com
- the untranslated-desktop-file check is obsolete, in factory
  all .desktop files are trimmed and marked - in all other projects
  (including devel projects) %%suse_update_desktop_file won't touch
  the files for translation only
* Mon Dec  5 2011 dmueller@suse.de
- fix invalid-suse-version-chec (bnc#732671)
* Tue Nov 29 2011 lnussel@suse.de
- fix devel-package-with-non-devel-group check (bnc#732897)
* Tue Nov 29 2011 lnussel@suse.de
- enable license check
* Mon Nov 28 2011 lnussel@suse.de
- add NetworkManager-openconnect to dbus whitelist (bnc#732915)
- add global filter for SuSEfirewall2's sysconfig file as setBadness in the
  package is not allowed
* Wed Nov 23 2011 projects@localside.net
- added: standard group 'citadel'
- added: standard user 'citadel'
- changed: addDetails('non-standard-uid', ... branch paket ...',
  'non-standard-uid', ... branch paket ...')
* Sun Aug 28 2011 opensuse@cboltz.de
- add vacation/vacation to valid group/user list
  (needed for PostfixAdmin's vacation.pl script)
* Wed Aug 24 2011 dmueller@suse.de
- avoid warning with shlib policy on libtool
* Sat Aug 20 2011 dmueller@suse.de
- check for versioned dependency on python(abi) (bnc#659068)
* Fri Aug 19 2011 dmueller@suse.de
- fix stripping of unknown polkit suffixes (bnc#711485)
* Fri Aug 12 2011 dmueller@suse.de
- update to 1.3:
  * Add --rawout option
  * Warn about non-ghost files in /var/run and /var/lock
  * Fix setting message type for reasons with badness threshold defined
  * Use "declare -F" instead of "type" to check if a bash function exists.
* Fri Aug 12 2011 dmueller@suse.de
- add jenkins/jenkins to valid group/user list
* Sat Aug  6 2011 jengelh@medozas.de
- Spelling fixes
* Fri Aug  5 2011 lnussel@suse.de
- add org.kde.kalarmrtcwake to dbus whitelist (bnc#707723)
* Fri Aug  5 2011 lnussel@suse.de
- only consider executable ELF files for
  non-position-independent-executable check
- add more users and groups from Factory
* Mon Aug  1 2011 lnussel@suse.de
- add lightdm user and group (bnc#708205)
* Fri Jul 29 2011 lnussel@suse.de
- add org.freedesktop.DisplayManager.conf (bnc#708205)
* Sat Jul 23 2011 toddrme2178@gmail.com
- remove obsolete knotification-requires check
- bump obsolete openSUSE version to 11.2
* Thu Jul 14 2011 lnussel@suse.de
- add more systemd dbus services to whitelist (bnc#705677)
* Wed Jul 13 2011 lnussel@suse.de
- CheckSUIDPermissions: use non-position-independent-executable as
  accepted upstream
* Thu Jun 23 2011 dmueller@suse.de
- remove some false positives of the no-dependency-on checker
* Wed Jun 15 2011 lnussel@suse.de
- fix library policy check complaining about non-ELF files (bnc#700067)
* Tue Jun  7 2011 lnussel@suse.de
- add colord to dbus whitelist (bnc#698250)
* Tue Jun  7 2011 lnussel@suse.de
- CheckPolkitPrivs.py: use different tag for non-fatal issues
- CheckBuildDate.py: print either file-contains-current-date or
  file-contains-current-date but not both
* Tue May 31 2011 lnussel@suse.de
- add check for /var/lock/subsys usage
* Tue May 24 2011 lnussel@suse.de
- disable source-or-patch-not-compressed. Not useful anymore.
* Fri May 20 2011 lnussel@suse.de
- add synche-connector (bnc#683956) to dbus whitelist
- update system-config-printer (bnc#694640) in dbus whiteliste
* Fri May 20 2011 dmueller@suse.de
- update legacy filter in shlib policy checker
* Thu May 19 2011 lnussel@suse.de
- new version 1.2
  * Check outdated or misspelled FSF addresses in text files.
* Tue May 17 2011 lnussel@suse.de
- update rpmlint-pie.diff and suse-file-var-run.diff with upstream
  accepted variant
* Wed May 11 2011 lnussel@suse.de
- don't filter non-standard-gid anymore
- add dir-or-file-in-var-lock check
- remove 'nobody' from standard users
* Tue May 10 2011 lnussel@suse.de
- add not-a-position-independent-executable check
* Thu May  5 2011 lnussel@suse.de
- add radvd user to known list
- add org.freedesktop.hostname1 to dbus whitelist (641924)
* Mon May  2 2011 lnussel@suse.de
- add account services (bnc#676638)
* Mon May  2 2011 lnussel@suse.de
- another try to fix InitScriptCheck.py (bnc#690961)
* Wed Apr 27 2011 dmueller@suse.de
- implement setFilterException()
- rediff noarch-lib64.diff and enable it again (bnc#663885)
* Tue Apr 26 2011 dmueller@suse.de
- make error description more clearn (bnc#686328)
* Sat Apr 23 2011 dmueller@suse.de
- fix abort in BinariesCheck
- fix sysv5-init-check.diff for real
* Thu Apr 21 2011 lnussel@suse.de
- fix sysv5-init-check.diff to not throw exception
* Wed Apr 20 2011 dmueller@suse.de
- fix sysv5-init-check.diff to check for preun, not postin
* Tue Apr 19 2011 lnussel@suse.de
- update CheckInitScripts.py:
  * add check for runlevel 4
  * clarify boot.* error
  * accept $null in start/stop tags
- also check for %%run_permissions if package doesn't actually need permissions
  handling
- merge suse-binarieschecks.diff and suse-hide-unstripped-outside-build.diff
  and fix the former
* Tue Apr 19 2011 lnussel@suse.de
- ignore dir-or-file-in-usr-local as it's handled by CheckFilelist.py
- non-standard-dir-in-usr dito
* Tue Apr 19 2011 lnussel@suse.de
- add urfkill (bnc#688328))
* Fri Apr 15 2011 dmueller@suse.de
- update to 1.1:
  - remove upstreamed patches
  * FilesCheck.py: Don't crash if a file cannot be opened
  * FilesCheck.py: Update expected Python 3.2 bytecode magic value
  * TagsCheck.py: Improve no-description-tag info message
  * TagsCheck.py: Improve changelog related info messages.
  * Pkg.py: Treat 'Unspecified' as a valid Group
  * TagsCheck.py: Add future and overflow checks for changelog
  * FilesCheck.py: Don't emit spurious executable perm warnings for
    docs with shebangs
  * FilesCheck.py: Don't read "head" of files for in each test
  * SpecCheck.py: Check source and patch file sizes and MD5 hashes
  * Pkg.py: Fix traceback when stringifying epoch-only versions
  * TagsCheck.py: Fix TypeError when outputting
  * Pkg.py: Make file capabilities available in PkgFile
- add check for missing rcXXX symlinks (FATE#310641)
* Mon Mar 21 2011 lnussel@suse.de
- add NetworkManager to dbus whitelist (bnc#681128)
- add wpa_supplicant to dbus whitelist (bnc#681116)
* Wed Mar 16 2011 dmueller@suse.de
- fix typo (bnc#675329)
* Thu Mar 10 2011 lnussel@suse.de
- add better help message for non-standard-uid
* Wed Feb 16 2011 lnussel@suse.de
- add kde backlight helper to whitelist (bnc#672145)
* Wed Feb  9 2011 lnussel@suse.de
- add webyast to dbus whitelist (bnc#660981)
* Thu Jan 13 2011 lnussel@suse.de
- add hal dbus system activation file too
* Wed Jan 12 2011 lnussel@suse.de
- add mumble-server to dbus white list (bnc#660784)
* Mon Jan 10 2011 lnussel@suse.de
- add NetworkManager-strongswan to dbus white list (bnc#656222)
* Sun Dec 19 2010 jw@novell.com
- Fix message for no-changelogname-tag:
  This is also caused by missing changes file.
  Original message posed a contradiction, in case the
  %%changelog section header was there.
* Wed Nov 24 2010 dmueller@suse.de
- remove filter for no-url-tag (bnc#642588)
- clarify wording for run_ldconfig check (bnc#637187)
- skip desktop files in /etc (bnc#604283)
* Fri Nov 19 2010 dmueller@suse.de
- fix exception on postgresql build
* Thu Nov 18 2010 lnussel@suse.de
- also check ghost files for permission violations
* Wed Nov 17 2010 lnussel@suse.de
- add check for %%set_permissions
* Tue Nov 16 2010 lnussel@suse.de
- modify match in CheckSUIDPermissions to work with new macros
- allow info messages even if badness scoring is used
* Mon Nov 15 2010 dmueller@suse.de
- change Documentation/SuSE to /SUSE (bnc#618716)
- whitelist "openSUSE" at start of Summary (bnc#618716)
* Sun Nov 14 2010 dmueller@suse.de
- remove invocations of expandMacro()
* Thu Nov 11 2010 dmueller@suse.de
- fix another exception in branding policy check (bnc#652628)
* Thu Nov  4 2010 lnussel@suse.de
- enable suse-hide-unstripped-outside-build.diff again
* Thu Nov  4 2010 lnussel@suse.de
- check for file system capabilities
- check for %%verifyscript and %%run_permissions
* Wed Nov  3 2010 dmueller@suse.de
- update to 1.0:
  * add support for PEP 3147 when handling python bytecode
  * various doc improvements
* Fri Oct 29 2010 lnussel@suse.de
- remove debug logging
- fix BrandingPolicy.py
* Wed Oct 27 2010 dmueller@suse.de
- fix supplements parsing (bnc#648404)
* Thu Oct 21 2010 dmueller@suse.de
- add build time check (bnc#635351)
* Tue Oct 19 2010 lnussel@suse.de
- init script check logic
* Tue Oct 19 2010 lnussel@suse.de
- add all currently known dbus services as legacy exception
* Tue Oct 19 2010 lnussel@suse.de
- add configurable whitelist to CheckDBUSServices.py
* Fri Oct 15 2010 dmueller@suse.de
- fix regression in suse-binariescheck.diff
* Tue Oct 12 2010 lnussel@suse.de
- add check for gnome and desktop related macros
* Sun Oct  3 2010 andrea@opensuse.org
- Added lxdm as a valid group and user
* Mon Sep 27 2010 dmueller@suse.de
- update to 0.99:
  * Add Python 2.7 magic number ( https://bugzilla.redhat.com/623607, Nils Philippsen)
* Mon Sep 27 2010 dmueller@suse.de
- update to 0.98:
  * Pkg.py, test/test.Pkg.py: Fix self-obsoletion bug with Provides
    containing Epoch.
  * Pkg.py: Don't stringify None Epoch to 'None' string in
    compareEVR().
  * Pkg.py: Sync rangeCompare() with yum 3.2.27.
  * TagsCheck.py: Reduce some spell check noise.
  * rpmlint: Fix handling of arguments containing spaces.
  * DocFilesCheck.py: Bypass doc file check earlier if package has no
    doc files.
* Thu Aug 19 2010 dimstar@opensuse.org
- Add suse-g-ir-chech.diff: *.gir belong in -devel packages.
* Sun Aug  8 2010 vuntz@opensuse.org
- Update suse-version.diff: last non-obsolete version of openSUSE
  is 11.1, and latest valid version of openSUSE is 11.4.
* Thu Jul 29 2010 dmueller@suse.de
- fix printWarning error in CheckBashisms
* Thu Jul 29 2010 puzel@novell.com
- add confusing-invalid-spec-name.patch
* Tue Jul 20 2010 guido+opensuse.org@berhoerster.name
- add BashismsCheck
* Mon Jul 12 2010 dmueller@suse.de
- add Development/Debug group (bnc#612044)
* Wed Jun 30 2010 lnussel@suse.de
- additionally look at the BUILD_DEBUG variable to determine whether
  a warning should be printed. Needs an updated 'build' script.
* Tue Jun 29 2010 lnussel@suse.de
- don't print unstripped binary warning when used with build script
  (bnc#618004)
* Mon Jun  7 2010 andrea@opensuse.org
- added "System/GUI/LXDE" as a valid rpmgroup
* Wed May  5 2010 lnussel@suse.de
- don't allow perl vendorarch in noarch packages
* Thu Apr 29 2010 dmueller@suse.de
- check for gethostbyname calls (bnc#506945)
* Thu Apr 29 2010 dmueller@suse.de
- fix branding check (bnc#579556)
* Wed Apr 28 2010 dmueller@suse.de
- fix exception in interpreter check
- restrict shlib-fixed-dependency to shlib-policy packages
- allow files in /tmp to be listed as %%ghost
* Tue Apr 27 2010 dmueller@suse.de
- tighten pkg-config check
* Mon Apr 26 2010 dmueller@suse.de
- check for missing xinetd.d (bnc#436326)
- check for files in /var/run (fate#303793)
* Thu Apr 22 2010 dmueller@suse.de
- check for live update problems (bnc#477649)
- rediff and enable the shared lib dependency check fix
* Wed Apr 21 2010 aj@suse.de
- Add some missing rpm groups and sort list.
* Mon Apr 19 2010 dmueller@suse.de
- tighten the interpreter check (bnc#574650)
* Fri Apr 16 2010 dmueller@suse.de
- suppress warnings about cron.d symlinks (bnc#591431)
* Tue Apr  6 2010 dmueller@suse.de
- workaround unicode error exceptions on non-utf8 filenames
* Fri Apr  2 2010 dmueller@suse.de
- rediff some suse specific patches
* Thu Mar 25 2010 dmueller@suse.de
- fix buildroot detection (bnc#584952)
* Fri Mar 19 2010 dmueller@suse.de
- update to 0.95:
  * Skip ghost files in files checks,  https://bugzilla.redhat.com/570086
  * Work around Python's ASCII non-TTY stdout and our non-ASCII output.
  * Omit spell check warnings for capitalized words that do not start a sentence.
  * Wrap bunch of long lines, tune comments and info messages.
  * Require rpm-python >= 4.4.2.2 for expandMacro() in r1729.
  * do not execute check if the network test are marked as disabled, and simplify the logic
  * do not expand the format of the filename format, (patch from Per Oyvind Karlsten )
* Sat Feb 27 2010 dmueller@suse.de
- update to 0.94:
  - rpm 4.8.0 support
  - better python bytecode checks
  - improved LSB/taglist
  - various fixes/patches upstreamed
* Thu Feb 25 2010 lnussel@suse.de
- update and enable CheckPolkitPrivs
* Fri Feb 19 2010 puzel@novell.com
- update suse version check (add 11.2, drop 10.3)
* Mon Feb  1 2010 lnussel@suse.de
- fix usr-arch.diff
- require python-magic as it's needed by some checks
* Wed Jan 13 2010 lnussel@suse.de
- suppress depmod warnings (bnc#456048)
* Sun Jan 10 2010 detlef@links2linux.de
- add some missing groups
* Sat Jan  9 2010 lnussel@suse.de
- disable badness for group check until we know the impact
* Fri Jan  8 2010 detlef@links2linux.de
- add a config file for standard RPM groups
* Thu Jan  7 2010 mvyskocil@suse.cz
- fixed bnc#566018 - no-ghost-alternative-file check makes no sense
  - fixed CheckAlternativesGhostFiles test, renamed the warnings to
    generic-name-not-in-filelist, generic-name-not-marked-as-ghost
* Sat Jan  2 2010 jengelh@medozas.de
- enable parallel build
* Sat Nov 14 2009 dmueller@suse.de
- update to 0.92:
  * various fixes and python 3 compatibility added
  * new checks for python compiled files
* Wed Oct  7 2009 dmueller@suse.de
- tighten the regex for libraries (bnc#544906)
* Wed Sep 30 2009 dmueller@suse.de
- fix exceptions in BinaryInfo
* Wed Sep  9 2009 dmueller@suse.de
- update to 0.90:
  * Makefile: 0.90.
  * rpmdiff: Add missing magic coding comment
  (https://bugzilla.redhat.com/508683, Michal Nowak).
  * TagsCheck.py: Fix incorrect info in self-obsoletion message.
  * FilesCheck.py: Output interpreter in non-executable-script
  warning, remove quotes from wrong-script-interpreter one.
  * Pkg.py: Remove stale comments.
  * TagsCheck.py: Code cleanup, NFC.
  * TagsCheck.py: improve percent-in-* message details.
  * TagsCheck.py: Remove obsolete-on-name check (superseded by
  self-obsoletion).
  * TagsCheck.py: Add check for self-obsoletion cases,
  https://bugzilla.redhat.com/461610
  * Pkg.py: Borrow various utilities from yum's rpmUtils.miscutils.
  * Makefile, rpmUtils: Revert previous commit.
  * Makefile, rpmUtils, rpmUtils/miscutils.py,
  rpmUtils/transaction.py: Borrow
  rpmUtils/{miscutils,transaction}.py from yum.
  * rpmdiff: Improve dependency formatting.
  * rpmdiff: Take Epoch into account in self-provides filtering.
  * Pkg.py: Improve legacy prereq tracking with new rpm versions.
  * BinariesCheck.py: Don't output missing-PT_GNU_STACK-section
  messages if readelf failed.
  * FilesCheck.py: Add check for debuginfo packages without sources.
  * FilesCheck.py: Allow more common files to be non-readable
  (https://bugzilla.redhat.com/226412).
  * FilesCheck.py: Revert relative symlink target normalization back
  to more aggressive.
  * BinariesCheck.py, Config.py, ConfigCheck.py, FHSCheck.py,
  FilesCheck.py, I18NCheck.py, MenuCheck.py, Pkg.py, PostCheck.py,
  TagsCheck.py, rpmdiff: Code cleanups.
  * FilesCheck.py: Do not check existence of relative link targets on
  the filesystem for consistency with absolute link target checks,
  improve dangling-*symlink info messages.
  * FilesCheck.py, Pkg.py: Be a bit stricter when normalizing link
  targets, do it earlier.
  * FilesCheck.py, Pkg.py: Improve link target normalization in
  symlink checks.
- filter cross-directory-hard-link as it is duplicate to a suse
  check
* Mon Sep  7 2009 dmueller@suse.de
- filter buildroot related checks (bnc#536594)
* Fri Aug 28 2009 mvyskocil@suse.cz
- Added CheckAlternativesGhostFiles.py - see bnc#534451 comment#17
* Wed Aug 26 2009 lnussel@suse.de
- disable bogus patch to InitScriptCheck.py. Causes failures and
  needs to be reworked
- fix and add weak dependencies patch again to make some suse checks
  work
* Wed Aug 26 2009 lnussel@suse.de
- fix CheckPkgConfig.py to work with rpmlint 0.87
* Wed Aug 26 2009 lnussel@suse.de
- refresh some patches to remove fuzz
- BuildIgnore rpmlint-mini as it is currently broken
* Mon Aug 24 2009 lnussel@suse.de
- don't import pprint in CheckSUIDPermissions.py
- remove /selinux again. No package except 'filesystem' is supposed
  to include that.
- add filter for FHS violation of skelcd type packages
- fix some more suse patches
* Mon Aug 10 2009 thomas@novell.com
- added /selinux to allowed prefixes in CheckFilelist.py
* Wed Jul 29 2009 lnussel@suse.de
- add cups to dbus whitelist (bnc#515977)
* Mon Jul 20 2009 lnussel@suse.de
- fix suse checks for 0.87
* Thu Jul 16 2009 lnussel@suse.de
- fix syntax error in suse-hide-unstripped-outside-build.diff
* Sun Jun 21 2009 dmueller@suse.de
- update to 0.87:
  * remove old rpm support
  * improved performance and compat with python 2.6
  * many pylint/pychecker code fixes
* Sat Apr  4 2009 dmueller@suse.de
- fix library policy checker being inactive due to API change
* Fri Feb 27 2009 dmueller@suse.de
- update to 0.85:
  * various new checks and fixes to existing checks
  * remove upstreamed patches
* Thu Feb 26 2009 lnussel@suse.de
- use separate error for sysconfig stuff (bnc#470965)
- move RCS detection to FilesCheck.py
- remove explicit requires on python, already handled by %%py_requires
* Mon Feb  9 2009 lnussel@suse.de
- remove check for /usr/share/info/dir from CheckFilelist.py,
  already in upstream FilesCheck.py
- fix exception for texinfo
* Mon Feb  2 2009 dmueller@suse.de
- improve information hint for perl blacklisted paths
- fix language list for sr (bnc#471254)
* Fri Jan 30 2009 lnussel@suse.de
- add exception for nfs-utils, texinfo and perl
- allow backup files if they are ghost files
* Fri Jan 23 2009 lnussel@suse.de
- add check for DBus Policy problems
* Tue Jan 13 2009 lnussel@suse.de
- CheckFilelist: optimize FHS check to only complain about wrong
  directories rather than hundreds of individual files
* Mon Jan 12 2009 lnussel@suse.de
- CheckFilelist: add exceptions for kde and pam
- CheckPolkitPrivs: use info instead of warning to avoid badness assignment
* Thu Jan  8 2009 lnussel@suse.de
- prefix dbus check with suse-
- add filelist check
* Wed Dec 17 2008 dmueller@suse.de
- add whitelist entry for libieee1284
* Thu Dec 11 2008 lnussel@suse.de
- add a check for PolicyKit privileges (disabled atm)
- add check for DBUS services
* Wed Dec  3 2008 dmueller@suse.de
- update suse version check (add 11.1, drop 10.2)
- check library packages more strict (bnc#456053)
- ignore shared objects in a versioned non-std subdir (bnc#435588)
* Thu Nov 20 2008 dmueller@suse.de
- only test for regular files in ChkPkgConfig check
* Fri Nov  7 2008 dmueller@suse.de
- add check for otherproviders() in branding packages
- correct kde4 related dependency checkers to not give false advises
- check for wrong-arch references in pkgconfig files (graphviz)
- lower false positives of untranslated-desktop files check
- support for checking .comment.SUSE.OPTs. real check has been
  left out for now
* Tue Nov  4 2008 lnussel@suse.de
- generate a different error for directories with setuid/setgid bit
* Tue Oct 28 2008 lnussel@suse.de
- add check for /etc/permissions violations
* Fri Oct  3 2008 dmueller@suse.de
- update to 0.84:
  * remove upstreamed patches
  * no significant changes
* Wed Sep  3 2008 dmueller@suse.de
- add description for useless-explicit-requires (bnc#405887)
* Wed Aug 20 2008 dmueller@suse.de
- rediff patch
* Mon Aug 18 2008 schwab@suse.de
- Fix name of completions file.
* Tue Aug 12 2008 dmueller@suse.de
- be more verbose in the lsb init script checks
* Mon Aug  4 2008 dmueller@suse.de
- change mandatory-lsb-keyword check to be in line with insserv
* Tue Jul 29 2008 dmueller@suse.de
- remove python-base in the warning as it is confusing.
  the warning itself is still valid though
- fix config typo
* Mon Jul 21 2008 dmueller@suse.de
- enable non-conffile-in-etc warning (bnc#409643)
- fix shlib policy dependency warnings (bnc#405280)
* Tue Jul  1 2008 dmueller@suse.de
- update cron dependency checker (bnc#400921)
* Sun Jun 29 2008 schwab@suse.de
- No PT_GNU_STACK on ia64 and ppc64.
* Fri Jun 27 2008 dmueller@suse.de
- also read /etc/rpmlint/factory.config
* Fri Jun 27 2008 dmueller@suse.de
- fix typo in suse-version check
* Sun Jun 22 2008 dmueller@suse.de
- update to 0.83:
  * removed upstreamed patches
  * a couple of new checks, bugfixes
* Wed Jun 18 2008 dmueller@suse.de
- fix exception in tags check (bnc#399655)
- add a warning for self-conflicts
* Thu Jun  5 2008 dmueller@suse.de
- fix naming policy check for lib64 based archs (bnc#392524)
* Tue May 13 2008 dmueller@suse.de
- fix typo in kde4 deps check
* Mon May  5 2008 dmueller@suse.de
- fix typo in branding policy check
* Fri May  2 2008 dmueller@suse.de
- readd cron check
- fix kmp check after the policy change
* Wed Apr 30 2008 dmueller@suse.de
- add checker for correct deps of kde4 packages
- add check for mono requirements (BNC#381979)
- improve branding policy checks
- add support for weak/reverse dependencies
- add checks for percent's in weak/reverse dependencies
- add checks for incorrect kmp dependencies (bnc384084#)
* Tue Apr 22 2008 dmueller@suse.de
- fix exception on testing for unversioned branding provides
* Mon Apr 21 2008 dmueller@suse.de
- suppress script warnings about /var/adm/fillup-templates (bnc#379601)
- add start of a branding policy checker
* Fri Apr 18 2008 jblunck@suse.de
- Fix some regex in BinariesCheck
* Thu Apr 17 2008 jblunck@suse.de
- Add symtab and debuginfo tests for static libs
* Thu Mar 13 2008 dmueller@suse.de
- autogenerate users/groups from autobuild (bnc#374601)
- suppress non-devel buildrequire dependency for tcl
- fix licenses symlink handling (bnc#370364)
- allow /usr/share/locale/be@latin (bnc#370418)
* Tue Mar 11 2008 dmueller@suse.de
- fix some false positives
* Mon Mar 10 2008 dmueller@suse.de
- add check for a really short description
* Thu Mar  6 2008 dmueller@suse.de
- be less restrictive in pkgconfig checks
* Mon Mar  3 2008 dmueller@suse.de
- suppress tag-not-utf8 warnings for now
* Thu Feb 28 2008 dmueller@suse.de
- add check for %%run_ldconfig
* Thu Feb 28 2008 dmueller@suse.de
- improve check output
* Tue Feb 26 2008 dmueller@suse.de
- improved tags check
- cleanups
* Mon Feb 25 2008 dmueller@suse.de
- reduce package-size-check false positives
- add another postscript check
* Tue Feb 19 2008 dmueller@suse.de
- fix typo in sorting routine
* Fri Feb 15 2008 dmueller@suse.de
- updated spec file name-guessing to catch more cases
- updated dot-in-identifier check
- suppression updates
* Tue Feb 12 2008 dmueller@suse.de
- update to 0.82:
  * some patches were upstreamed
  * small bugfixes
- rework fix for bnc#354177 to consider python bytecode
  arch-independent again, but catch it in arch-dependent paths
* Sat Feb  9 2008 dmueller@suse.de
- fix some minor buglets
* Tue Feb  5 2008 dmueller@suse.de
- consider python bytecode to not be arch independent (bnc#354177)
- improve postcheck to ignore unexpanded macros in comments (bnc#355306)
- check binary rpath for perl version dependency (bnc#355053)
- add check for unversioned self-provides
- update suse checks from SVN
- check for dot's in dependencies - forbidden by autobuild policy
* Wed Jan 23 2008 dmueller@suse.de
- improve documentation
* Mon Jan 14 2008 dmueller@suse.de
- check for libtool wrapper scripts being packaged (#353240)
* Wed Dec 12 2007 dmueller@suse.de
- reapply patch-detection fix
* Mon Dec  3 2007 dmueller@suse.de
- add suppression for libzypp
- fix wrong indentation in verify-buildrequires
* Fri Nov 30 2007 dmueller@suse.de
- bugfixes in check-mkdir-buildroot
- bugfix in percent-post check
- check for buildroot in %%post scriptlets
- remove abused legacy shared lib policy exceptions
- suppression update
* Mon Nov 26 2007 dmueller@suse.de
- fix suppression for internal packages
* Fri Nov 23 2007 dmueller@suse.de
- add suppression for non-remote_fs on boot.* (#340588)
* Wed Nov 21 2007 dmueller@suse.de
- add warning for non-utf8 filenames (#343216)
* Tue Nov  6 2007 dmueller@suse.de
- more prereq checks
* Mon Nov  5 2007 dmueller@suse.de
- suppression update
- add more prereq checks
* Fri Nov  2 2007 dmueller@suse.de
- fix prereq parsing code (#336712)
- update the obsolete-suse-version check to include 10.0 and 11.0
- fix prereq checks to check for coreutils
* Wed Oct 31 2007 dmueller@suse.de
- reporting format change-back got rejected by upstream,
  so adopt other changes to deal with it
* Tue Oct 30 2007 dmueller@suse.de
- change back reporting format to list the severity
  first
- add more legacy suppressions found by library policy
  fix
* Mon Oct 29 2007 dmueller@suse.de
- also check for Library Policy errors in /opt/kde3/lib
* Mon Oct 29 2007 dmueller@suse.de
- update to 0.81:
  * various new checks, some bugfixes
  * many patches upstreamed
  * rediffed all other patches
- NOTE: output format has changed from
  W: package check-id ..
  to
  package.<arch>: W: check-id ..
* Sun Oct  7 2007 dmueller@suse.de
- another round of updates
* Fri Oct  5 2007 dmueller@suse.de
- library policy legacy suppression update
* Mon Oct  1 2007 mmarek@suse.cz
- added 'mysql' to the list of standard users and groups
- removed 'jonas' (dropped package) from that list
* Tue Sep 25 2007 dmueller@suse.de
- update library policy checker for libgcc and libcaca
- check for /usr/share/gnome/help in documentation checks (#310134)
* Thu Sep 20 2007 dmueller@suse.de
- add check for non-whitelisted filedependencies (#326803)
* Mon Sep  3 2007 dmueller@suse.de
- fix hardlink check for /bin
* Sat Sep  1 2007 schwab@suse.de
- Fix last change.
* Fri Aug 31 2007 dmueller@suse.de
- fix off-by-one in hardlink check
* Fri Aug 31 2007 dmueller@suse.de
- fix exception in DuplicatesCheck
* Thu Aug 30 2007 dmueller@suse.de
- fix buildroot false positive
- check for hardlinks across partitions (#304167)
* Wed Aug 29 2007 dmueller@suse.de
- improve mkdir-installroot check
- fix rpmlint package regarding check above ;)
* Wed Aug 29 2007 mmarek@suse.cz
- improved the non-devel-buildrequires check
- added some default filters for non-devel-buildrequires and
  unneccessary-buildrequires
* Wed Aug 22 2007 dmueller@suse.de
- check for wrong cleaning of buildroot in %%install (#300232)
- check for obscure and unneccessary buildrequires
- add an icon size check (#163547)
* Tue Aug 21 2007 dmueller@suse.de
- refine the $remote_fs dependency check
* Sun Aug 12 2007 dmueller@suse.de
- suppression update
* Sat Aug 11 2007 dmueller@suse.de
- improved macro checks
- documentation update
* Fri Aug 10 2007 dmueller@suse.de
- detect makefile junk (#217472)
- suppression update
- fix a couple of false positives
* Tue Jul 31 2007 dmueller@suse.de
- fix package-with-huge-docs check to not complain about
  documentation-only packages
- remove verbosity from the shared library packaging policy check
* Tue Jul 24 2007 dmueller@suse.de
- fix man page check false positives
- make package-with-huge-docs check less verbose
* Tue Jul 17 2007 dmueller@suse.de
- accept lua as a builtin shell
- fix false positives on filesystem package
- add check for init scrips missing $remote_fs
* Wed Jul 11 2007 dmueller@suse.de
- adjust library policy suppressions for opal and pwlib (#290347)
- fix readme check (#291150)
* Mon Jul  9 2007 dmueller@suse.de
- its also a devel package if it provides a -devel subpackage (#289735)
* Wed Jul  4 2007 dmueller@suse.de
- suppress %%config check for now (#286231)
* Tue Jun 26 2007 dmueller@suse.de
- fix typo in devel-rpmgroup check
* Mon Jun 25 2007 dmueller@suse.de
- another update list of legacy packages
* Sat Jun 23 2007 dmueller@suse.de
- update list of legacy packages
* Fri Jun 22 2007 dmueller@suse.de
- suppressions for mono related packages (#282121)
* Fri Jun 22 2007 dmueller@suse.de
- fix the bzip2/gzip confusion again
* Fri Jun 22 2007 dmueller@suse.de
- update list of legacy packages
* Thu Jun 21 2007 dmueller@suse.de
- add list of legacy package names with non-policy conform
  package name
- check updates from SVN
* Thu Jun 21 2007 dmueller@suse.de
- suppression update
- suppress devel-file-in-non-devel package if its just a compat
  symlink to another .so
- avoid unstripped binaries warnings in BETA
- fix filesystem lint false positives
* Wed Jun 13 2007 dmueller@suse.de
- suppression update
- add descriptions to sysv5 init checks
- use readelf for binary info to improve performace
- check if source patch/tarballs is not bzip2'ed and bigger
  than 100k (suse packaging conventions requirement)
- check if package contains excessive sized documentation
* Mon Jun 11 2007 dmueller@suse.de
- hide errors related to .packlist files from perl
  still need to figure out though why they're there
* Mon Jun 11 2007 dmueller@suse.de
- fix build
* Sat Jun  9 2007 dmueller@suse.de
- make the buildroot check work
- make the buildroot check factor 10-15 faster
- fix the pkgconfig check
* Fri Jun  8 2007 dmueller@suse.de
- fix warning-hide hack (#279865)
- description update
* Fri Jun  8 2007 dmueller@suse.de
- hide unstripped-binary-or-object warning outside build (#279865)
- fix typo in library policy check
- adopt library checks for suse library packaging policy
- add check for unnecessarily packaged files
- description update
- suppression update
* Thu May 31 2007 dmueller@suse.de
- suppression update
- fix various checks
- add checks for init scripts
* Wed May 30 2007 dmueller@suse.de
- update LibraryPolicy Checker
* Tue May 29 2007 dmueller@suse.de
- suppression update
- fix XDG menu checker to also include non-/usr paths
- fix ghost-file-creation check to skip missingok files (#278761)
* Mon May 28 2007 dmueller@suse.de
- suppression-update
- Library Policy Checker crash fixes (#278592)
* Sat May 26 2007 dmueller@suse.de
- add description for missing lsb tags check
- fix obsolete-not-provided for yast2-provides
- fix devel-file check matching module names (e.g. apache2)
* Fri May 25 2007 dmueller@suse.de
- avoid spurious executable warnings for docdatadir/examples
- add LibraryPolicy checker from Richard (warning only)
- suppression update
* Thu May 24 2007 dmueller@suse.de
- fix suppression for qa_ packages
- fix exceptions caused by DesktopTranslation check
- fix crash caused by trailing colons in requires
* Thu May 24 2007 dmueller@suse.de
- fix file paths in Duplicate and DesktopTranslation checks
* Thu May 24 2007 dmueller@suse.de
- update sourced-dirs list
- add some more standard users
- add suppression for devel-file-in-non-devel package in java
- filter some more noise
* Wed May 23 2007 dmueller@suse.de
- add descriptions for obsolete suse version check
- suppress some more noise
- don't run duplicates check for source rpms
* Wed May 23 2007 dmueller@suse.de
- suppress errors for cross-avr-*
- suppress devel-packaging-naming errors for gcc41, gcc42
* Wed May 23 2007 dmueller@suse.de
- group output by check and put errors last (#276943)
- suppress some more noise (#277308)
- suppress %%ifarch-applied-patch (#277316)
- more suppressions for misnamed devel packages (#277317)
* Wed May 23 2007 dmueller@suse.de
- Suppress errors about platform dependent code in /usr/share
  if its inside a platform-dependant subdirectory
- Suppress devel-file-in-non-devel-package for systemtap (#277338)
- Make sure that the package fails if there is any syntax
  error anywhere
* Tue May 22 2007 dmueller@suse.de
- typo fix
* Tue May 22 2007 dmueller@suse.de
- update config
* Sat May 19 2007 coolo@suse.de
- add three more checks
* Thu May 17 2007 dmueller@suse.de
- update Duplicates Check to not crash on ghost files
* Tue May 15 2007 dmueller@suse.de
- suppress bzip2 related warnings
- no documentation for lib packages
* Tue May 15 2007 coolo@suse.de
- add a check how much space is wasted by duplicated files
* Mon May 14 2007 dmueller@suse.de
- remove rpm-devel requirement
- add check for filerequires on /usr/bin/env
- fix syntax errors in previous change
* Mon May 14 2007 coolo@suse.de
- add a check for /opt/kde3 not in %%doc or in %%lang
- fix files not in %%lang check
* Wed May  9 2007 dmueller@suse.de
- remove tabs from sources
* Mon May  7 2007 dmueller@suse.de
- fix desktop file check (#252482)
* Sat May  5 2007 dmueller@suse.de
- allow extensions to LSB starting with "X-" (#271495)
* Fri May  4 2007 dmueller@suse.de
- remove check for usedforbuild tag. magic happens and
  it is created automatically
* Wed Apr 18 2007 dmueller@suse.de
- add spec checks for obsolete suse hacks
* Wed Apr 18 2007 dmueller@suse.de
- update to 0.80:
  * many more checks
- suppression updates
* Thu Apr  5 2007 dmueller@suse.de
- suppressions for OpenOffice and linux-kernel-headers
* Thu Apr  5 2007 dmueller@suse.de
- update suppressions
* Wed Nov  8 2006 dmueller@suse.de
- fix compatibility with rpm-python of sles9 (#216081)
* Mon Sep 11 2006 dmueller@suse.de
- update to 0.77:
  * updated checks regarding FHS compliance
  * some python-lint fixlets
* Wed Apr 12 2006 dmueller@suse.de
- update to 0.76
* Fri Mar 24 2006 dmueller@suse.de
- update to 0.75
* Tue Mar 21 2006 dmueller@suse.de
- suppress some glibc related errors (#157906)
* Wed Feb 22 2006 dmueller@suse.de
- add km to the list of valid locales
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  9 2006 dmueller@suse.de
- add check for untranslated desktop files
* Tue Dec 20 2005 dmueller@suse.de
- fix i18n subdir check
* Thu Dec 15 2005 dmueller@suse.de
- filter init-script-name-with-dot /etc/init.d/boot.* and
  script-without-shellbang /etc/profile.d/*
* Thu Nov 24 2005 dmueller@suse.de
- update to 0.71
- strip "requires-on-release" for now, too much noise
* Fri Jul 22 2005 dmueller@suse.de
- ignore dir-or-file-in-opt
* Mon Jun 20 2005 coolo@suse.de
- update to 0.70
* Thu Jun 16 2005 dmueller@suse.de
- upgrade to rpmlint 0.69
- split out the config file from the SUSE patch
* Thu Nov 11 2004 coolo@suse.de
- remove some MDK specific tests and add some SUSE specific tests
* Mon Feb 23 2004 hmacht@suse.de
- building as non-root
* Wed Jun 11 2003 coolo@suse.de
- initial version
